<li class="grp-float-left submit-button-container">
    <input type="submit"
           value="{{ button_value }}"
           class="default transition-{{ transition_name }}"
           name="_fsmtransition-{{ fsm_field_name }}-{{ transition_name }}" />
</li>
